@@ -7,6 +7,7 @@
 # 22 Feb 2021 : Run tests with 'allowMarkdown=FALSE'.  More 'tablesggOpt' tests.
 # 04 Mar 2021 : Orthogonality of styles and scale.
 # 25 Apr 2021 : More thorough test of 'scale'.
+# 24 Jan 2024 : Change deprecated 'size' arg to 'element_rect' to 'linewidth'.
 
 if (!get0("IS_PKG", ifnotfound=TRUE)) {
   pdf(paste0("tests_1n2.", Sys.Date(), ".pdf"))
@@ -332,7 +333,7 @@ print(plt, position=c("center", "top"))
 plt2 <- plot(tbl, scale=0.8, 
              title=c("Small version (scale=0.8), with borders:", 
                      "panel (blue), plot (red)")) + 
-        theme(panel.background=element_rect(color="blue", size=1), 
+        theme(panel.background=element_rect(color="blue", linewidth=1), 
               plot.background=element_rect(color="red"))  # add borders
 print(plt2, position=c(0.03, 0.45), newpage=FALSE)
 print(plt3, position=c(0.97, 0.0), newpage=FALSE)
